==> onboarding-springboot-0.11.0-sources.jar: org/kie/kogito/examples/onboarding/SetupHRProcess.java <==
package org.kie.kogito.examples.onboarding;

import org.jbpm.process.core.datatype.impl.type.ObjectDataType;
import org.jbpm.ruleflow.core.RuleFlowProcessFactory;
import org.drools.core.util.KieFunctions;

@org.springframework.stereotype.Component("onboarding.setupHR")
public class SetupHRProcess extends org.kie.kogito.process.impl.AbstractProcess<org.kie.kogito.examples.onboarding.SetupHRModel> {

    @org.springframework.beans.factory.annotation.Autowired(required = false)
    java.util.Collection<org.kie.api.runtime.process.WorkItemHandler> handlers;

    org.kie.kogito.examples.Application app;

    public SetupHRProcess() {
    }

    @org.springframework.beans.factory.annotation.Autowired()
    public SetupHRProcess(org.kie.kogito.examples.Application app) {
        super(app.config().process());
        this.app = app;
    }

    public org.kie.kogito.examples.onboarding.SetupHRProcessInstance createInstance(org.kie.kogito.examples.onboarding.SetupHRModel value) {
        return new org.kie.kogito.examples.onboarding.SetupHRProcessInstance(this, value, this.createLegacyProcessRuntime());
    }

    public org.kie.kogito.examples.onboarding.SetupHRProcessInstance createInstance(java.lang.String businessKey, org.kie.kogito.examples.onboarding.SetupHRModel value) {
        return new org.kie.kogito.examples.onboarding.SetupHRProcessInstance(this, value, businessKey, this.createLegacyProcessRuntime());
    }

    public org.kie.kogito.examples.onboarding.SetupHRModel createModel() {
        return new org.kie.kogito.examples.onboarding.SetupHRModel();
    }

    public org.kie.kogito.examples.onboarding.SetupHRProcessInstance createInstance(org.kie.kogito.Model value) {
        return this.createInstance((org.kie.kogito.examples.onboarding.SetupHRModel) value);
    }

    public org.kie.kogito.examples.onboarding.SetupHRProcessInstance createInstance(java.lang.String businessKey, org.kie.kogito.Model value) {
        return this.createInstance(businessKey, (org.kie.kogito.examples.onboarding.SetupHRModel) value);
    }

    public SetupHRProcess configure() {
        super.configure();
        return this;
    }

    protected void registerListeners() {
    }

    public org.kie.api.definition.process.Process legacyProcess() {
        RuleFlowProcessFactory factory = RuleFlowProcessFactory.createProcess("onboarding.setupHR");
        factory.variable("employee", new ObjectDataType("org.kie.kogito.examples.onboarding.Employee"), "customTags", null);
        factory.variable("manager", new ObjectDataType("java.lang.String"), "customTags", null);
        factory.variable("department", new ObjectDataType("java.lang.String"), "customTags", null);
        factory.name("setupHR");
        factory.packageName("org.kie.kogito.examples.onboarding");
        factory.dynamic(false);
        factory.version("1.0");
        factory.visibility("Private");
        factory.metaData("TargetNamespace", "http://www.omg.org/bpmn20");
        org.jbpm.ruleflow.core.factory.EndNodeFactory endNode1 = factory.endNode(1);
        endNode1.name("End");
        endNode1.terminate(false);
        endNode1.metaData("UniqueId", "_D5D0E3CA-BCFE-4C4B-A9C5-4573F9E1ABED");
        endNode1.metaData("x", 478);
        endNode1.metaData("width", 56);
        endNode1.metaData("y", 100);
        endNode1.metaData("height", 56);
        endNode1.done();
        org.jbpm.ruleflow.core.factory.StartNodeFactory startNode2 = factory.startNode(2);
        startNode2.name("Start");
        startNode2.interrupting(true);
        startNode2.metaData("UniqueId", "_F5EC087B-0E01-4F48-8135-B8CB7BE8D0CC");
        startNode2.metaData("x", 100);
        startNode2.metaData("width", 56);
        startNode2.metaData("y", 100);
        startNode2.metaData("height", 56);
        startNode2.done();
        org.jbpm.ruleflow.core.factory.WorkItemNodeFactory workItemNode3 = factory.workItemNode(3);
        workItemNode3.name("Assign department and manager");
        workItemNode3.workName("AssignDepartmentAndManager");
        workItemNode3.workParameter("Model", "onboarding");
        workItemNode3.workParameter("Namespace", "test");
        workItemNode3.workParameter("Decision", "department/first");
        workItemNode3.workParameter("TaskName", "AssignDepartmentAndManager");
        workItemNode3.inMapping("employee", "employee");
        workItemNode3.outMapping("manager", "manager");
        workItemNode3.outMapping("department", "department");
        workItemNode3.done();
        workItemNode3.metaData("UniqueId", "_C2C840B8-C669-4134-91DD-81B664982F57");
        workItemNode3.metaData("elementname", "Assign department and manager");
        workItemNode3.metaData("x", 244);
        workItemNode3.metaData("width", 154);
        workItemNode3.metaData("y", 77);
        workItemNode3.metaData("height", 102);
        factory.connection(3, 1, "_A8AA8CBD-0CC2-4E4A-AF32-415FDFE599F7");
        factory.connection(2, 3, "_ACDDDC63-2696-434C-BE17-FE9B3A39112A");
        factory.validate();
        return factory.getProcess();
    }

    @javax.annotation.PostConstruct()
    public void init() {
        this.activate();
    }
}

==> onboarding-springboot-0.12.0-sources.jar: org/kie/kogito/examples/onboarding/SetupHRProcess.java <==
package org.kie.kogito.examples.onboarding;

import org.jbpm.process.core.datatype.impl.type.ObjectDataType;
import org.jbpm.ruleflow.core.RuleFlowProcessFactory;
import org.drools.core.util.KieFunctions;

@org.springframework.stereotype.Component("onboarding.setupHR")
public class SetupHRProcess extends org.kie.kogito.process.impl.AbstractProcess<org.kie.kogito.examples.onboarding.SetupHRModel> {

    @org.springframework.beans.factory.annotation.Autowired(required = false)
    java.util.Collection<org.kie.api.runtime.process.WorkItemHandler> handlers;

    org.kie.kogito.examples.Application app;

    public SetupHRProcess() {
    }

    @org.springframework.beans.factory.annotation.Autowired()
    public SetupHRProcess(org.kie.kogito.examples.Application app) {
        super(app.config().process());
        this.app = app;
    }

    public org.kie.kogito.examples.onboarding.SetupHRProcessInstance createInstance(org.kie.kogito.examples.onboarding.SetupHRModel value) {
        return new org.kie.kogito.examples.onboarding.SetupHRProcessInstance(this, value, this.createProcessRuntime());
    }

    public org.kie.kogito.examples.onboarding.SetupHRProcessInstance createInstance(java.lang.String businessKey, org.kie.kogito.examples.onboarding.SetupHRModel value) {
        return new org.kie.kogito.examples.onboarding.SetupHRProcessInstance(this, value, businessKey, this.createProcessRuntime());
    }

    public org.kie.kogito.examples.onboarding.SetupHRModel createModel() {
        return new org.kie.kogito.examples.onboarding.SetupHRModel();
    }

    public org.kie.kogito.examples.onboarding.SetupHRProcessInstance createInstance(org.kie.kogito.Model value) {
        return this.createInstance((org.kie.kogito.examples.onboarding.SetupHRModel) value);
    }

    public org.kie.kogito.examples.onboarding.SetupHRProcessInstance createInstance(java.lang.String businessKey, org.kie.kogito.Model value) {
        return this.createInstance(businessKey, (org.kie.kogito.examples.onboarding.SetupHRModel) value);
    }

    public SetupHRProcess configure() {
        super.configure();
        return this;
    }

    protected void registerListeners() {
    }

    public org.kie.api.definition.process.Process process() {
        RuleFlowProcessFactory factory = RuleFlowProcessFactory.createProcess("onboarding.setupHR");
        factory.variable("employee", new ObjectDataType("org.kie.kogito.examples.onboarding.Employee"), "customTags", null);
        factory.variable("manager", new ObjectDataType("java.lang.String"), "customTags", null);
        factory.variable("department", new ObjectDataType("java.lang.String"), "customTags", null);
        factory.name("setupHR");
        factory.packageName("org.kie.kogito.examples.onboarding");
        factory.dynamic(false);
        factory.version("1.0");
        factory.visibility("Private");
        factory.metaData("TargetNamespace", "http://www.omg.org/bpmn20");
        org.jbpm.ruleflow.core.factory.EndNodeFactory endNode1 = factory.endNode(1);
        endNode1.name("End");
        endNode1.terminate(false);
        endNode1.metaData("UniqueId", "_D5D0E3CA-BCFE-4C4B-A9C5-4573F9E1ABED");
        endNode1.metaData("x", 478);
        endNode1.metaData("width", 56);
        endNode1.metaData("y", 100);
        endNode1.metaData("height", 56);
        endNode1.done();
        org.jbpm.ruleflow.core.factory.StartNodeFactory startNode2 = factory.startNode(2);
        startNode2.name("Start");
        startNode2.interrupting(true);
        startNode2.metaData("UniqueId", "_F5EC087B-0E01-4F48-8135-B8CB7BE8D0CC");
        startNode2.metaData("x", 100);
        startNode2.metaData("width", 56);
        startNode2.metaData("y", 100);
        startNode2.metaData("height", 56);
        startNode2.done();
        org.jbpm.ruleflow.core.factory.WorkItemNodeFactory workItemNode3 = factory.workItemNode(3);
        workItemNode3.name("Assign department and manager");
        workItemNode3.workName("AssignDepartmentAndManager");
        workItemNode3.workParameter("Model", "onboarding");
        workItemNode3.workParameter("Namespace", "test");
        workItemNode3.workParameter("Decision", "department/first");
        workItemNode3.workParameter("TaskName", "AssignDepartmentAndManager");
        workItemNode3.inMapping("employee", "employee");
        workItemNode3.outMapping("manager", "manager");
        workItemNode3.outMapping("department", "department");
        workItemNode3.done();
        workItemNode3.metaData("UniqueId", "_C2C840B8-C669-4134-91DD-81B664982F57");
        workItemNode3.metaData("elementname", "Assign department and manager");
        workItemNode3.metaData("x", 244);
        workItemNode3.metaData("width", 154);
        workItemNode3.metaData("y", 77);
        workItemNode3.metaData("height", 102);
        factory.connection(3, 1, "_A8AA8CBD-0CC2-4E4A-AF32-415FDFE599F7");
        factory.connection(2, 3, "_ACDDDC63-2696-434C-BE17-FE9B3A39112A");
        factory.validate();
        return factory.getProcess();
    }

    @javax.annotation.PostConstruct()
    public void init() {
        this.activate();
    }
}
